@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 
 import datetime
 
@@ -18,7 +18,10 @@ logging.basicConfig(level=logging.INFO)
 def logsstash_logging(args):
     logsstash_host, logsstash_port = args.logstash.split(":")
     logsstash_logger = logging.getLogger()
-    logsstash_logger.addHandler(logstash.LogstashHandler(logsstash_host, int(logsstash_port), version=1))
+    logsstash_logger.addHandler(logstash.LogstashHandler(logsstash_host,
+                                                         int(logsstash_port),
+                                                         version=1,
+                                                         message_type="driver-parser"))
 
 def packet_summary(pkt):
     ip_src = None
@@ -153,8 +156,6 @@ def parse_file(args):
                           )
         if serial not in serial_collector:
             serial_collector.append(serial)
-            payload_d = payload.__dict__()
-            payload_d['type'] = "driver-parser"
-            logging.info({"terminal_serial": payload.terminal_serial}, extra=payload_d)
+            logging.info({"terminal_serial": payload.terminal_serial}, extra=payload.__dict__())
     logging.debug("Stop")
     return 0
